@@ -20,7 +20,7 @@
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: m_who.c 1007 2007-11-24 10:08:52Z swalsh $*/
+/* $Id: m_who.c 1061 2009-06-13 18:03:13Z tjfontaine $*/
 
 
 #include "stdinc.h"
@@ -66,7 +66,7 @@ _moddeinit(void)
 {
   mod_del_cmd(&who2_msgtab);
 }
-const char *_version = "$Revision: 1007 $";
+const char *_version = "$Revision: 1061 $";
 #endif
 
 /* Internally defined stuffs */
@@ -568,10 +568,10 @@ do_who_channel(struct Client *source_p, struct Channel *chptr, int showall)
     else if(IsOper(source_p) && IsInvisible(target_p))
       status[i++] = '%';
 
-    if (target_p->flags & CHFL_CHANOP)
+    if (ms->flags & CHFL_CHANOP)
       status[i++] = '@';
-    else if (target_p->flags & CHFL_VOICE)
-      status[i++] = '%';
+    else if (ms->flags & CHFL_VOICE)
+      status[i++] = '+';
 
     status[i] = '\0';
     sendto_one(source_p, form_str(RPL_WHOREPLY), me.name, source_p->name,
